from django.db import models

# Create your models here.

class Slider(models.Model):
    name = models.CharField(max_length = 255)
    slider_img = models.ImageField()
    created_on = models.DateTimeField(auto_now_add = True, null = True, blank = True)
    updated_on = models.DateTimeField(auto_now = True, null = True, blank = True)



# Generated by Django 3.2.16 on 2022-12-12 15:33

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Slider',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('slider_img', models.ImageField(upload_to='')),
                ('created_on', models.DateTimeField(auto_now_add=True, null=True)),
                ('updated_on', models.DateTimeField(auto_now=True, null=True)),
            ],
        ),
    ]



# File sets up the django environment, used by other scripts that need to
# execute in django land
import os
import django
from django.conf import settings

BASE_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), "receipts"))

def boot_django():
    settings.configure(
        BASE_DIR=BASE_DIR,
        DEBUG=True,
        DATABASES={
            "default":{
                "ENGINE":"django.db.backends.sqlite3",
                "NAME": os.path.join(BASE_DIR, "db.sqlite3"),
            }
        },
        INSTALLED_APPS=(
            "slider",
        ),
        TIME_ZONE="UTC",
        USE_TZ=True,
    )
    django.setup()


import json

from slider.models import Slider
from django import  template
from django.core import serializers

from slider.serializers import SliderTemplate

register = template.Library()

@register.inclusion_tag('slider_list.html')
def render_slider():
    sliders = Slider.objects.all()
    serializers = SliderTemplate(sliders, many = True)
    print(json.loads(json.dumps(serializers.data)))
    return {
        # "sliders": list(sliders.values("id", "slider_img__url"))
        # "slider_data": json.loads(json.dumps(serializers.data))
    }



import json

from django.shortcuts import render
from django.views.generic import TemplateView
# Create your views here.
from slider.models import Slider
from slider.serializers import SliderTemplate


class SliderIndex(TemplateView):
    template_name = "index.html"

    def get(self, request):

        sliders = Slider.objects.all()

        serializers = SliderTemplate(sliders, many = True)

        slider_data = json.loads(json.dumps(serializers.data))
        context = { "sliders": sliders, "slider_data": slider_data}

        return render(request, self.template_name, context)


#!/usr/bin/env python
#import os, sys
import sys
from unittest import TestSuite

from boot_django import boot_django

# call the django setup routine
boot_django()

default_labels = ["slider.tests", ]

def get_suite(labels=default_labels):
    from django.test.runner import DiscoverRunner
    runner = DiscoverRunner(verbosity=1)
    failures = runner.run_tests(labels)
    if failures:
        sys.exit(failures)

    # in case this is called from setup tools, return a test suite
    return TestSuite()


if __name__ == "__main__":
    labels = default_labels
    if len(sys.argv[1:]) > 0:
        labels = sys.argv[1:]

    get_suite(labels)


from django.test import TestCase

# Create your tests here.
from slider.models import Slider


class SliderTest(TestCase):
    fixtures = ["sliders.json"]

    def test_slider_total(self):
        sliders = Slider.objects.all()
        total = sliders.count()
        self.assertEqual(2, total)




from rest_framework import serializers

from slider.models import Slider


class SliderTemplate(serializers.ModelSerializer):
    slider_img_url = serializers.SerializerMethodField()

    def get_slider_img_url(self, obj):
        return obj.slider_img.url

    class Meta:
        model = Slider
        fields = "__all__"